//
//  FlickrPhotoTableViewController.m
//  PictureFly
//
//  Created by Jennifer Clark on 12/12/12.
//  Copyright (c) 2012 Jennifer Clark. All rights reserved.
//

#import "FlickrPhotoTableViewController.h"
#import "FlickrFetcher.h"
#import "ImageViewController.h"
#import "MapViewController.h"
#import "FlickrPhotoAnnotation.h"
#import "SplitViewBarButtonItemPresenter.h"

@interface FlickrPhotoTableViewController () <MapViewControllerDelegate>

@property (nonatomic, strong) NSArray *photos; //array of Flickr photo dictionaries
@property (nonatomic, strong) UIImage *thumbnailImage;
@end

@implementation FlickrPhotoTableViewController

@synthesize photos = _photos, thumbnailImage = _thumbnailImage, mapViewController = _mapViewController;


- (void) awakeFromNib
{
    [super awakeFromNib];
    self.splitViewController.delegate = self;
}


- (id <SplitViewBarButtonItemPresenter>) splitViewBarButtonItemPresenter
{
    id detailVC = [self.splitViewController.viewControllers lastObject];
    
    if (![detailVC conformsToProtocol:@protocol(SplitViewBarButtonItemPresenter)]) {
        detailVC = nil;
    }
    return detailVC;
}


- (BOOL) splitViewController:(UISplitViewController *)svc
    shouldHideViewController:(UIViewController *)vc
               inOrientation:(UIInterfaceOrientation)orientation
{
    return [self splitViewBarButtonItemPresenter] ? UIInterfaceOrientationIsPortrait(orientation) : NO;
}


- (void) splitViewController:(UISplitViewController *)svc
      willHideViewController:(UIViewController *)aViewController
           withBarButtonItem:(UIBarButtonItem *)barButtonItem
        forPopoverController:(UIPopoverController *)pc
{
    barButtonItem.title = self.title;
    [self splitViewBarButtonItemPresenter].splitViewBarButtonItem = barButtonItem;
}


- (void) splitViewController:(UISplitViewController *)svc
      willShowViewController:(UIViewController *)aViewController
   invalidatingBarButtonItem:(UIBarButtonItem *)barButtonItem
{
    [self splitViewBarButtonItemPresenter].splitViewBarButtonItem = nil;
}


- (NSArray *)mapAnnotations
{
    NSMutableArray *annotations = [NSMutableArray arrayWithCapacity:[self.photos count]];
    for (NSDictionary *photo in self.photos) {
        [annotations addObject:[FlickrPhotoAnnotation annotationForPhoto:photo]];
    }
    return annotations;
}


- (void)updateSplitViewDetail
{
    id detail = [self.splitViewController.viewControllers lastObject];
    if ([detail isKindOfClass: [MapViewController class]]) {
        MapViewController *mapVC = (MapViewController *)detail;
        
        self.mapViewController = mapVC;
        mapVC.delegateforTableViewController = self;
        mapVC.annotations = [self mapAnnotations]; 
    }
}

- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
        if ([segue.destinationViewController isKindOfClass:[ImageViewController class]]) {
            ImageViewController *ivc = (ImageViewController *)segue.destinationViewController;
            NSIndexPath *indexPath = [self.tableView indexPathForCell:sender];
            NSDictionary *photo = [self.photos objectAtIndex:indexPath.row];
            ivc.imageURL = [FlickrFetcher urlForPhoto:photo format:FlickrPhotoFormatLarge];
            ivc.title = [photo objectForKey:FLICKR_PHOTO_TITLE];
        }
   
        if ([segue.identifier isEqualToString:@"iPhoneMap"]) {
            NSLog(@"we are preparing for map segue");
               id destinationViewController = segue.destinationViewController;
                    if ([destinationViewController isKindOfClass:[MapViewController class]]) {
                        MapViewController *mapVCIphone = (MapViewController *)destinationViewController;
                        mapVCIphone.delegateforTableViewController = self;
                        self.mapViewController = mapVCIphone;
                        mapVCIphone.annotations = [self mapAnnotations];
                    }
        }
}

- (void)mapViewController:(MapViewController *)sender imageForAnnotation:(id<MKAnnotation>)annotation
{
    FlickrPhotoAnnotation *fpa = (FlickrPhotoAnnotation *)annotation;
    dispatch_queue_t downloadQueue = dispatch_queue_create("flickr annotation image downloader", NULL);
    dispatch_async(downloadQueue, ^{
        NSURL *url = [FlickrFetcher urlForPhoto:fpa.photo format:FlickrPhotoFormatSquare];
        NSData *data = [NSData dataWithContentsOfURL:url];
        UIImage *image = [UIImage imageWithData:data];
        dispatch_async(dispatch_get_main_queue(), ^{
            [self.mapViewController setAnnotationImage:image];
        });
    });
}  


- (void)setPhotos:(NSArray *)photos
{
    if (_photos != photos) {
        _photos = photos;
        [self updateSplitViewDetail];
        if (self.tableView.window) [self.tableView reloadData];
    }
}

- (void) viewDidLoad
{
    [super viewDidLoad];
}

- (IBAction)refresh:(id)sender
{
    UIActivityIndicatorView *spinner = [[UIActivityIndicatorView alloc]initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleGray];
    [spinner startAnimating];
    self.navigationItem.leftBarButtonItem = [[UIBarButtonItem alloc]initWithCustomView:spinner];
    
    dispatch_queue_t downloadQueue = dispatch_queue_create("flickr downloader", NULL);
    dispatch_async(downloadQueue, ^{
        NSArray *photos = [FlickrFetcher recentGeoreferencedPhotos];
        dispatch_async(dispatch_get_main_queue(), ^{
            self.photos = photos;
            self.navigationItem.leftBarButtonItem = sender;
        });
    });
}


- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [self.photos count];
}


- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Flicker Photo";
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier forIndexPath:indexPath];
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:CellIdentifier];
    }
    // Configure the cell...
    NSDictionary *photo = [self.photos objectAtIndex:indexPath.row];
    cell.textLabel.text = [photo objectForKey:FLICKR_PHOTO_TITLE];
    cell.detailTextLabel.text = [photo objectForKey:FLICKR_PHOTO_OWNER];
    
    return cell;
    
}

@end
