//
//  MapViewController.m
//  PictureFly
//
//  Created by Jennifer Clark on 12/17/12.
//  Copyright (c) 2012 Jennifer Clark. All rights reserved.
//

#import "MapViewController.h"
#import <MapKit/MapKit.h>
#import "FlickrPhotoTableViewController.h"

@interface MapViewController () <MKMapViewDelegate>
@property (weak, nonatomic) IBOutlet MKMapView *mapView;
@property (strong, nonatomic) MKAnnotationView *currentAnnotationView;
@property (strong, nonatomic)  UIActivityIndicatorView *spinner;
@property (nonatomic, weak) IBOutlet UIToolbar *toolbar;
@end

@implementation MapViewController
@synthesize annotations = _annotations;
@synthesize mapView = _mapView, mapViewIphone = _mapViewIphone;
@synthesize delegateforTableViewController = _delegateforTableViewController;
@synthesize currentAnnotationView = _currentAnnotationView;
@synthesize spinner = _spinner;
@synthesize toolbar = _toolbar;
@synthesize splitViewBarButtonItem = _splitViewBarButtonItem;


- (void)setSplitViewBarButtonItem:(UIBarButtonItem *)splitViewBarButtonItem
{
    if (_splitViewBarButtonItem != splitViewBarButtonItem)  { 
        NSMutableArray *toolBarItems = [self.toolbar.items mutableCopy];
        if (_splitViewBarButtonItem) [toolBarItems removeObject:_splitViewBarButtonItem];
        if (splitViewBarButtonItem) [toolBarItems insertObject:splitViewBarButtonItem atIndex:0];
        self.toolbar.items = toolBarItems;         
        _splitViewBarButtonItem = splitViewBarButtonItem;
    }
    
}

- (void)updateMapView
{
       if (self.splitViewController) {
        if (self.mapView.annotations) [self.mapView removeAnnotations:self.mapView.annotations];
        if (self.annotations) [self.mapView addAnnotations:self.annotations];
       }   else {
            if (self.mapViewIphone.annotations) [self.mapViewIphone removeAnnotations:self.mapViewIphone.annotations];
            if (self.annotations) [self.mapViewIphone addAnnotations:self.annotations];
           }
}


- (void)setAnnotations:(NSArray *)annotations
{
    _annotations = annotations;
    [self updateMapView];
}


- (void)setMapView:(MKMapView *)mapView
{
    _mapView = mapView;
    [self updateMapView];
}


- (void)setMapViewIphone:(MKMapView *)mapViewIphone
{
    _mapViewIphone = mapViewIphone;
    [self updateMapView];
}


- (MKAnnotationView *)mapView:(MKMapView *)mapView viewForAnnotation:(id<MKAnnotation>)annotation
{
    //creates generic annotations
    MKAnnotationView *aView = [mapView dequeueReusableAnnotationViewWithIdentifier:@"MapVC"];
    if (!aView) {
        aView = [[MKPinAnnotationView alloc]initWithAnnotation:annotation reuseIdentifier:@"MapVC"];
        aView.canShowCallout = YES;
        aView.leftCalloutAccessoryView = [[UIImageView alloc]initWithFrame:CGRectMake(0, 0, 30, 30)];
        aView.annotation = annotation;
        [(UIImageView *)aView.leftCalloutAccessoryView setImage:nil];
    }
    return aView;
}


- (void)mapView:(MKMapView *)mapView didSelectAnnotationView:(MKAnnotationView *)aView
{
    self.currentAnnotationView = aView;
    self.spinner = [[UIActivityIndicatorView alloc]initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleGray];
    [self.currentAnnotationView.leftCalloutAccessoryView addSubview:self.spinner];
    [self.spinner startAnimating];
    [self.delegateforTableViewController mapViewController:self imageForAnnotation:self.currentAnnotationView.annotation];
}


- (void)setAnnotationImage:(UIImage *)image
{
    [(UIImageView *)self.currentAnnotationView.leftCalloutAccessoryView setImage:image];
    [self.spinner stopAnimating];
}


- (void)viewDidLoad
{
    [super viewDidLoad];
}


- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

@end
